@@ -1,6 +1,6 @@
 package App::Greple::xlate;
 
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 =encoding utf-8
 
@@ -101,7 +101,7 @@ Specify the output format for original and translated text.
 
 =over 4
 
-=item B<conflict>
+=item B<conflict>, B<cm>
 
 Print original and translated text in L<git(1)> conflict marker format.
 
@@ -134,9 +134,10 @@ You can retrieve only Japanese text by the B<unifdef> command:
 
 Print original and translated text separated by single blank line.
 
-=item B<none>
+=item B<xtxt>
 
-If the format is C<none> or unkown, only translated text is printed.
+If the format is C<xtxt> (translated text) or unkown, only translated
+text is printed.
 
 =back
 
@@ -286,6 +287,7 @@ sub opt :lvalue { ${$opt{+shift}} }
 my $current_file;
 
 our %formatter = (
+    xtxt => undef,
     none => undef,
     conflict => sub {
 	join '',
@@ -295,6 +297,7 @@ our %formatter = (
 	    $_[1],
 	    ">>>>>>> $lang_to\n";
     },
+    cm => 'conflict',
     ifdef => sub {
 	join '',
 	    "#ifdef $lang_from\n",
@@ -308,6 +311,12 @@ our %formatter = (
     discard => sub { '' },
     );
 
+# aliases
+for (keys %formatter) {
+    next if ! $formatter{$_} or ref $formatter{$_};
+    $formatter{$_} = $formatter{$formatter{$_}} // die;
+}
+
 my $old_cache = {};
 my $new_cache = {};
 my $xlate_cache_update;
@@ -507,6 +516,7 @@ option --xlate-color \
 option --xlate --xlate-color --color=never
 option --xlate-fold --xlate --xlate-fold-line
 option --xlate-labor --xlate --deepl-method=clipboard
+option --xlabor --xlate-labor
 
 option --cache-clear --xlate-cache=clear
 
